<?php
/*
Plugin Name: WP Prio Head
Description: Fügt benutzerdefinierten Code zum Header-Bereich hinzu
Version: 1.1
Author: Kovynt.com
Author URI: https://kovynt.com/
Plugin URI: https://kovynt.com/?s=wp-prio-head
*/

// Verhindere direkten Zugriff
if (!defined('ABSPATH')) {
    exit;
}

// Admin-Menü hinzufügen
function wp_prio_head_menu() {
    add_options_page(
        'WP Prio Head Einstellungen',
        'WP Prio Head',
        'manage_options',
        'wp-prio-head',
        'wp_prio_head_options_page'
    );
}
add_action('admin_menu', 'wp_prio_head_menu');

// Einstellungen registrieren
function wp_prio_head_settings() {
    register_setting('wp_prio_head_options', 'wp_prio_head_enabled');
    register_setting('wp_prio_head_options', 'wp_prio_head_position');
    register_setting('wp_prio_head_options', 'wp_prio_head_code');
}
add_action('admin_init', 'wp_prio_head_settings');

// Optionen-Seite erstellen
function wp_prio_head_options_page() {
    ?>
    <div class="wrap">
        <h1>WP Prio Head Einstellungen</h1>
        <form method="post" action="options.php">
            <?php
            settings_fields('wp_prio_head_options');
            do_settings_sections('wp_prio_head_options');
            ?>
            <table class="form-table">
                <tr>
                    <th scope="row">Position</th>
                    <td>
                        <select name="wp_prio_head_position">
                            <option value="first" <?php selected(get_option('wp_prio_head_position'), 'first'); ?>>Als erstes</option>
                            <option value="last" <?php selected(get_option('wp_prio_head_position'), 'last'); ?>>Als letztes</option>
                        </select>
                    </td>
                </tr>
                <tr>
                    <th scope="row">Header Code</th>
                    <td>
                        <textarea name="wp_prio_head_code" rows="10" cols="50" class="large-text code"><?php echo esc_textarea(get_option('wp_prio_head_code')); ?></textarea>
                    </td>
                </tr>
                <tr>
                    <th scope="row">Status</th>
                    <td>
                        <select name="wp_prio_head_enabled">
                            <option value="1" <?php selected(get_option('wp_prio_head_enabled'), 1); ?>>An</option>
                            <option value="0" <?php selected(get_option('wp_prio_head_enabled'), 0); ?>>Aus</option>
                        </select>
                    </td>
                </tr>
            </table>
            <?php submit_button(); ?>
        </form>
    </div>
    <?php
}

// Code zum Header hinzufügen
function wp_prio_head_insert_code() {
    if (get_option('wp_prio_head_enabled') == 1) {
        $code = get_option('wp_prio_head_code');
        if (!empty($code)) {
            if (get_option('wp_prio_head_position') == 'first') {
                add_action('wp_head', function() use ($code) {
                    echo $code;
                }, 1);
            } else {
                add_action('wp_head', function() use ($code) {
                    echo $code;
                }, 999);
            }
        }
    }
}
add_action('init', 'wp_prio_head_insert_code');

// Aktivierungshook
function wp_prio_head_activate() {
    // Standardwerte setzen
    add_option('wp_prio_head_enabled', 0);
    add_option('wp_prio_head_position', 'first');
    add_option('wp_prio_head_code', '');
}
register_activation_hook(__FILE__, 'wp_prio_head_activate');

// Deaktivierungshook
function wp_prio_head_deactivate() {
    // Optionen beim Deaktivieren nicht löschen
}
register_deactivation_hook(__FILE__, 'wp_prio_head_deactivate');

// Deinstallationshook
function wp_prio_head_uninstall() {
    // Optionen beim Deinstallieren löschen
    delete_option('wp_prio_head_enabled');
    delete_option('wp_prio_head_position');
    delete_option('wp_prio_head_code');
}
register_uninstall_hook(__FILE__, 'wp_prio_head_uninstall');